[llvm-commits] CVS: llvm/include/llvm/CodeGen/SelectionDAGISel.h
Evan Cheng
evan.cheng at apple.com
Sat Oct 14 01:31:07 PDT 2006
Changes in directory llvm/include/llvm/CodeGen:
SelectionDAGISel.h updated: 1.26 -> 1.27
---
Log message:
Start checking from the root of the matched sub-tree.
---
Diffs of the changes: (+2 -2)
SelectionDAGISel.h | 4 ++--
1 files changed, 2 insertions(+), 2 deletions(-)
Index: llvm/include/llvm/CodeGen/SelectionDAGISel.h
diff -u llvm/include/llvm/CodeGen/SelectionDAGISel.h:1.26 llvm/include/llvm/CodeGen/SelectionDAGISel.h:1.27
--- llvm/include/llvm/CodeGen/SelectionDAGISel.h:1.26 Tue Oct 10 22:58:02 2006
+++ llvm/include/llvm/CodeGen/SelectionDAGISel.h Sat Oct 14 03:30:53 2006
@@ -71,8 +71,8 @@
}
/// CanBeFoldedBy - Returns true if the specific operand node N of U can be
- /// folded during instruction selection?
- virtual bool CanBeFoldedBy(SDNode *N, SDNode *U) { return true; }
+ /// folded during instruction selection that starts at Root?
+ virtual bool CanBeFoldedBy(SDNode *N, SDNode *U, SDNode *Root) { return true;}
/// CreateTargetHazardRecognizer - Return a newly allocated hazard recognizer
/// to use for this target when scheduling the DAG.
More information about the llvm-commits
mailing list